### PUT TODOs HERE, FUTURE WILL DO IT FOR YOU ###
1. ~~video.write()~~ Apr 30 2025
2. ~~video read~~ Apr 30 2025
3. Image class but C H W(should be H W C)
4. ~SSIM/PSNR/FID/... metrics implementations~ May 26 2025
5. save a list of images to gif(or video)
6. ~~add lossless video save function~~ May 26 2025